@@ -6,7 +6,10 @@ from urllib.request import urlopen
 
 from .vars import DATA
 from ..kernels import MetaKernel
-from ..misc import wget
+from ..misc import wget, logger
+
+
+log_esa_crema, debug_esa_crema = logger('ESA CReMA', info_stdout=True)
 
 
 class CReMACollection(type):
@@ -29,25 +32,25 @@ class CReMACollection(type):
         return cls.__name__
 
     def __repr__(cls):
-        n = len(cls.metakernels)
+        n = len(cls.metakernels())
         if n == 0:
             s = f'No metakernels available. Please Update your list: `{cls}.update()`.'
         else:
             s = '\n - '.join([
                 f'{n} metakernel' + ('s are ' if n > 1 else ' is ') + 'available:',
-                *sorted(cls.metakernels.keys(), reverse=True)
+                *sorted(cls.metakernels().keys(), reverse=True)
             ])
 
         return f'<{cls.__class__.__name__}> {s}'
 
     def __len__(cls):
-        return len(cls.metakernels)
+        return len(cls.metakernels())
 
     def __iter__(cls):
-        return iter(cls.metakernels.values())
+        return iter(cls.metakernels().values())
 
     def __contains__(cls, other):
-        return str(other) in cls.metakernels.keys()
+        return str(other) in cls.metakernels().keys()
 
     def __getitem__(cls, key):
         return cls.get(key)
@@ -59,7 +62,7 @@ class CReMACollection(type):
     def __dict__(cls):
         return cls.__class__.__dict__
 
-    @property
+    # @property
     def metakernels(cls) -> dict:
         """Dict of available metakernels."""
         if not cls.__mk:
@@ -143,7 +146,7 @@ class CReMACollection(type):
         if str(key) not in cls:
             raise KeyError(f'Unknown {cls} `{key}`')
 
-        return cls.metakernels[str(key)]
+        return cls.metakernels()[str(key)]
 
     def remove(cls, key, cache=True, delete_file=False):
         """Remove CReMA metakernel.
@@ -197,30 +200,20 @@ class CReMACollection(type):
                 ])
             )
 
-    def update(cls, quiet=False):
+    def update(cls):
         """Download and update CReMA list.
 
         The list of CReMA is cached internally.
 
-        Parameters
-        ----------
-        quiet: bool, optional
-            Disable verbose prints (default: ``False``).
-
         """
-        for crema in cls.get_data(quiet=quiet):
+        for crema in cls.get_data():
             cls.add(*crema, cache=False, force_download=True)
 
         cls.save_cache()
 
-    def get_data(cls, quiet=False):
+    def get_data(cls):
         """Get CReMA list from ESA website.
 
-        Parameters
-        ----------
-        quiet: bool, optional
-            Disable verbose prints (default: ``False``).
-
         Returns
         -------
         [CReMAMetaKernel, …]
@@ -232,15 +225,18 @@ class CReMACollection(type):
             If the parsed data from ESA website is invalid.
 
         """
-        if not quiet:
-            print('> Downloading the latest list of CReMA from ESA website...', end='')
+        log_esa_crema.info('Downloading the latest list of CReMA from ESA website...')
 
         # Download the data
         with urlopen(cls.URL) as resp:
             encoder = resp.headers.get_content_charset('utf-8')
             content = resp.read().decode(encoder)
             content = content.replace('&nbsp;', '')
-            content = ' '.join((content.split()))  # Strip lines
+            content = content.replace('\u200b', '')  # Remove zero width space characters
+            content = content.replace(',', ';')  # Remove commas
+            content = ' '.join((content.split()))    # Strip lines
+
+        log_esa_crema.debug('Download complete.')
 
         # Parse the data
         parser = CReMAParser()
@@ -251,13 +247,12 @@ class CReMACollection(type):
 
         parser.close()
 
+        log_esa_crema.debug('Parsing complete.')
+
         # Check header validity
         if header != ('CReMA', 'Overview', 'Main Update', 'Metakernel'):
             raise ValueError(f'Invalid table header: `{header}`')  # pragma: no cover
 
-        if not quiet:
-            print(' -- Done')
-
         return cremas
 
     def purge(cls):
