@@ -3,8 +3,13 @@
 from pathlib import Path
 from urllib.request import urlretrieve
 
+from .logger import logger
 
-def wget(url, fout, skip=False, force=False, verbose=True):
+
+log_download, debug_download = logger('Download', info_stdout=True)
+
+
+def wget(url, fout, skip=False, force=False):
     """Web download.
 
     Parameters
@@ -18,8 +23,6 @@ def wget(url, fout, skip=False, force=False, verbose=True):
         Has the priority over :py:attr:`force`.
     force: bool, optional
         Force download even if the file exists (default: `False`).
-    verbose: bool, optional
-        Verbose download.
 
     Returns
     -------
@@ -35,6 +38,10 @@ def wget(url, fout, skip=False, force=False, verbose=True):
     ----
     The missing sub-directories will be created.
 
+    By default, logging is set at INFO level.
+    Use :py:func:`debug_download` function to
+    increase or disable the logging output.
+
     """
     fname = Path(fout)
 
@@ -49,12 +56,10 @@ def wget(url, fout, skip=False, force=False, verbose=True):
         fname.parent.mkdir(parents=True, exist_ok=True)
 
         # Download the content and save it in `fname`
-        if verbose:
-            print(f'> Downloading: {url}', end='')
+        log_download.info(url)
 
         urlretrieve(url, fname)
 
-        if verbose:
-            print(' -- Success')
+        log_download.debug('Saved in: %s', fname)
 
     return fname
