@@ -8,9 +8,11 @@ Projection are based on PROJ project:
 
 from .equi import Equirectangular
 from .equi_gc import Equirectangular as EquirectangularGC
+from .ticks import UnitFormatter
 
 
 __all__ = [
     'Equirectangular',
     'EquirectangularGC',
+    'UnitFormatter',
 ]
