@@ -130,7 +130,7 @@ class Equirectangular(GroundProjection):
             'UNIT["Meter", 1]]'
         )
 
-    def xy(self, lon_e, lat):
+    def xy(self, lon_e, lat, value=None):
         """Convert latitude/longitude coordinates in map coordinates.
 
         Parameters
@@ -139,6 +139,8 @@ class Equirectangular(GroundProjection):
             East longitude [degree].
         lat: float or array
             Latitude [degree].
+        value: float or array
+            Value associated with the point.
 
         Returns
         -------
@@ -167,7 +169,7 @@ class Equirectangular(GroundProjection):
         elif np.ndim(x) > 0 and np.ndim(y) == 0:
             y = np.broadcast_to(y, x.shape)
 
-        return np.array([x, y])
+        return np.array([x, y]) if value is None else np.array([x, y, value])
 
     def lonlat(self, x, y):
         """Convert map coordinates in latitude/longitude coordinates.
@@ -204,6 +206,51 @@ class Equirectangular(GroundProjection):
 
         return lon_e, lat
 
+    def xy_plot(self, lons_e, lats, values=None):
+        """Plot latitude/longitude coordinates in a map.
+
+        Parameters
+        ----------
+        lons_e: float or array
+            East longitude [degree].
+        lats: float or array
+            Latitude [degree].
+        values: float or array
+            Values associated with the points.
+
+        Returns
+        -------
+        float or array, float or array
+            X-Y map coordinates.
+
+        """
+        x, y, v = self.xy(lons_e, lats, value=lats if values is None else values)
+        cross = np.abs(x[1:] - x[:-1]) > self.xc  # Larger than half the map: [i+1] - [i]
+
+        if cross.any():
+            verts = [[x[0], y[0], v[0]]]
+            for i, crossed in enumerate(cross):
+                if crossed:
+                    if x[i] > self.x_0:
+                        _x1, _x2 = self.x_0 + self.xc, self.x_0 - self.xc  # Right cross
+                        _f = (self.xc + self.x_0 - x[i]) / (2 * self.xc + x[i + 1] - x[i])
+                    else:
+                        _x1, _x2 = self.x_0 - self.xc, self.x_0 + self.xc  # Left cross
+                        _f = (self.xc - self.x_0 + x[i]) / (2 * self.xc + x[i] - x[i + 1])
+
+                    _y = (y[i + 1] - y[i]) * _f + y[i]
+                    _v = (v[i + 1] - v[i]) * _f + v[i]
+
+                    verts.append([_x1, _y, _v])
+                    verts.append([np.nan, np.nan, np.nan])
+                    verts.append([_x2, _y, _v])
+
+                verts.append([x[i + 1], y[i + 1], v[i + 1]])
+
+            x, y, v = np.transpose(verts)
+
+        return (x, y) if values is None else (x, y, v)
+
     def xy_path(self, path):
         """Convert path vertices in map coordinates.
 
