@@ -13,7 +13,41 @@ from .categories import (Category, CategoriesCollection,
                          SubCategory, SubCategoriesCollection)
 
 from ..projections import Equirectangular
-from ..trajectory import Trajectory
+
+
+class AbstractEmptyROI:
+    """Empty Region of Interest.
+
+    Result on null ROI intersection.
+
+    """
+    def __str__(self):
+        return ''
+
+    def __repr__(self):
+        return '<EmptyROI>'
+
+    def __call__(self, **_):
+        return PathPatch(Path([(None, None)]))
+
+    def __contains__(self, _):
+        return False
+
+    def __and__(self, other):
+        """And (&) operator."""
+        return self
+
+    def __xor__(self, other):
+        """Hat (^) operator."""
+        return self
+
+    @staticmethod
+    def contains(pts):
+        """Null intersection."""
+        return np.full_like(pts, False)
+
+
+EmptyROI = AbstractEmptyROI()
 
 
 class ROI(AbstractItem):
@@ -45,6 +79,14 @@ class ROI(AbstractItem):
     def __contains__(self, pt):
         return self.contains(pt).any()
 
+    def __and__(self, other):
+        """And (&) operator."""
+        return self if other in self else EmptyROI
+
+    def __xor__(self, other):
+        """Hat (^) operator."""
+        return self if other not in self else EmptyROI
+
     @property
     def vertices(self):
         """ROI vertices."""
@@ -134,10 +176,10 @@ class ROI(AbstractItem):
 
         Parameters
         ----------
-        pts: np.array or trajectory.Trajectory
+        pts: np.array
             List of geographic point(s): ``(lon_e, lat)`` or ``[(lon_e, lat), …]``.
-            If a :py:obj:`Trajectory` is provided, the intersection
-            will be performed on the its sub-observer points.
+            If an object with :py:attr:`lonlat` attribute/property is provided,
+            the intersection will be performed on these points.
 
         Returns
         -------
@@ -156,8 +198,8 @@ class ROI(AbstractItem):
         If the point is on the edge of the contour it will be excluded.
 
         """
-        if isinstance(pts, Trajectory):
-            return self.contains(pts.sub_obs_pts[1:])
+        if hasattr(pts, 'lonlat'):
+            return self.contains(pts.lonlat)
 
         if np.ndim(pts) == 1:
             return self.contains([pts])
@@ -176,6 +218,20 @@ class ROIsCollection(AbstractCollection):
     def __call__(self, **kwargs):
         return self.collection(**kwargs)
 
+    def __contains__(self, key):
+        if hasattr(key, 'lonlat'):
+            return self.contains(key.lonlat).any()
+
+        return key in self.data
+
+    def __and__(self, other):
+        """And (&) operator."""
+        return self.intersect(other)
+
+    def __xor__(self, other):
+        """Hat (^) operator."""
+        return self.intersect(other, outside=True)
+
     def collection(self, **kwargs):
         """ROI patches collection with default ROI color."""
         patches = [roi.patch() for roi in self]
@@ -200,6 +256,40 @@ class ROIsCollection(AbstractCollection):
         """Default edgecolors."""
         return [roi.color if hasattr(roi, 'color') else default for roi in self]
 
+    def contains(self, pts):
+        """Check if a list of points are in the ROIs collection."""
+        return np.any([roi.contains(pts) for roi in self], axis=0)
+
+    def intersect(self, obj, outside=False):
+        """Intersection between the trajectory and an object.
+
+        Parameters
+        ----------
+        obj: any
+            Trajectory-like object to intersect the ROIsCollection.
+        outside: bool, optional
+            Return the invert of the intersection (default: `False`).
+
+        Returns
+        -------
+        ROIsCollection
+            Masked trajectory.
+
+        Raises
+        ------
+        AttributeError
+            If the comparison object doest have a :py:func:`constains`
+            test function.
+
+        """
+        coll = ROIsCollection()
+        for key, roi in self.items():
+            inside = obj in roi
+            if (inside and not outside) or (not inside and outside):
+                coll[key] = roi
+
+        return coll
+
 
 class ROIsCollectionWithCategories(ROIsCollection):
     """ROIs collection with categories."""
@@ -217,13 +307,13 @@ class ROIsCollectionWithCategories(ROIsCollection):
         return s
 
     def __contains__(self, key):
-        if key in self.rois.keys():
+        if key in self.rois:
             return True
 
-        if key in self.categories.keys():
+        if key in self.categories:
             return True
 
-        if key in self.subcategories.keys():
+        if key in self.subcategories:
             return True
 
         return False
